==> istio-model-v1alpha3-6.4.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/TCPHealthCheckConfigFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TCPHealthCheckConfigFluentImpl<A extends TCPHealthCheckConfigFluent<A>> extends BaseFluent<A> implements TCPHealthCheckConfigFluent<A>{
  public TCPHealthCheckConfigFluentImpl() {
  }
  public TCPHealthCheckConfigFluentImpl(TCPHealthCheckConfig instance) {
    this.withHost(instance.getHost()); 
    this.withPort(instance.getPort()); 
  }
  private String host;
  private Integer port;
  public String getHost() {
    return this.host;
  }
  public A withHost(String host) {
    this.host=host; return (A) this;
  }
  public Boolean hasHost() {
    return this.host != null;
  }
  public Integer getPort() {
    return this.port;
  }
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  public Boolean hasPort() {
    return this.port != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TCPHealthCheckConfigFluentImpl that = (TCPHealthCheckConfigFluentImpl) o;
    if (host != null ? !host.equals(that.host) :that.host != null) return false;
    if (port != null ? !port.equals(that.port) :that.port != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(host,  port,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (host != null) { sb.append("host:"); sb.append(host + ","); }
    if (port != null) { sb.append("port:"); sb.append(port); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/TCPHealthCheckConfigFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TCPHealthCheckConfigFluentImpl<A extends TCPHealthCheckConfigFluent<A>> extends BaseFluent<A> implements TCPHealthCheckConfigFluent<A>{
  public TCPHealthCheckConfigFluentImpl() {
  }
  public TCPHealthCheckConfigFluentImpl(TCPHealthCheckConfig instance) {
    if (instance != null) {
      this.withHost(instance.getHost());
      this.withPort(instance.getPort());
    }
  }
  private String host;
  private Integer port;
  public String getHost() {
    return this.host;
  }
  public A withHost(String host) {
    this.host=host; return (A) this;
  }
  public Boolean hasHost() {
    return this.host != null;
  }
  public Integer getPort() {
    return this.port;
  }
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  public Boolean hasPort() {
    return this.port != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TCPHealthCheckConfigFluentImpl that = (TCPHealthCheckConfigFluentImpl) o;
    if (!java.util.Objects.equals(host, that.host)) return false;

    if (!java.util.Objects.equals(port, that.port)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(host,  port,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (host != null) { sb.append("host:"); sb.append(host + ","); }
    if (port != null) { sb.append("port:"); sb.append(port); }
    sb.append("}");
    return sb.toString();
  }
  
}
